@@ -1,4 +1,4 @@
-# ABSTRACT: Zanata (http://zanata.org/) synchronization plugin for Serge
+# ABSTRACT: Serge Zanata translation server (http://zanata.org/) synchronization plugin
 
 package Serge::Sync::Plugin::TranslationService::zanata;
 
@@ -7,9 +7,8 @@ use parent Serge::Sync::Plugin::Base::TranslationService, Serge::Interface::SysC
 use strict;
 
 use Serge::Util qw(subst_macros);
-use version;
 
-our $VERSION = qv('0.907.1');
+our $VERSION = '0.10';
 
 sub name {
     return 'Zanata translation server (http://zanata.org/) synchronization plugin';
@@ -24,29 +23,19 @@ sub init {
 
     $self->merge_schema({
         # Project configuration file, eg zanata.xml
-        project_config   => 'STRING',
+        project_config => 'STRING',
         # User configuration, eg /home/user/.config/zanata.ini
-        user_config      => 'STRING',
+        user_config => 'STRING',
         # Type of push to perform on the server:
-        #   'source' pushes source documents only
-        #   'both' (default) pushes both source and translation documents
-        push_type        => 'STRING',
+        #   source  pushes source documents only
+        #   both (default) pushes both source and translation documents
+        push_type => 'STRING',
         # The base directory for storing zanata cache files. Default is current directory.
-        cache_dir        => 'STRING',
+        cache_dir => 'STRING',
         # Whether to use an Entity cache when fetching documents.
-        use_cache        => 'BOOLEAN',
+        use_cache => 'BOOLEAN',
         # Whether to purge the cache before performing the pull operation
-        purge_cache      => 'BOOLEAN',
-        # File types to locate and transmit to the server when using project type 'file'
-        file_types       => 'ARRAY',
-        # Whether to enable debug logging. Default is false.
-        debug            => 'BOOLEAN',
-        # Whether to output full execution error messages (stacktraces). Default is false.
-        errors           => 'BOOLEAN',
-        # Whether verification of SSL certificates should be disabled. Default is false.
-        disable_ssl_cert => 'BOOLEAN',
-        #  Dry run: don't change any data, on the server or on the filesystem. Default is false.
-        dry_run          => 'BOOLEAN'
+        purge_cache => 'BOOLEAN'
     });
 }
 
@@ -61,11 +50,6 @@ sub validate_data {
     $self->{data}->{cache_dir} = subst_macros($self->{data}->{cache_dir});
     $self->{data}->{use_cache} = subst_macros($self->{data}->{use_cache});
     $self->{data}->{purge_cache} = subst_macros($self->{data}->{purge_cache});
-    $self->{data}->{file_types} = subst_macros($self->{data}->{file_types});
-    $self->{data}->{debug} = subst_macros($self->{data}->{debug});
-    $self->{data}->{errors} = subst_macros($self->{data}->{errors});
-    $self->{data}->{disable_ssl_cert} = subst_macros($self->{data}->{disable_ssl_cert});
-    $self->{data}->{dry_run} = subst_macros($self->{data}->{dry_run});
 
     die "'project_config' not defined" unless defined $self->{data}->{project_config};
     die "'project_config', which is set to '$self->{data}->{project_config}', does not point to a valid file.\n" unless -f $self->{data}->{project_config};
@@ -106,22 +90,6 @@ sub run_zanata_cli {
         $command .= ' --locales '.$locales_as_string;
     }
 
-    if (defined $self->{data}->{debug} && $self->{data}->{debug}) {
-        $command .= ' --debug';
-    }
-
-    if (defined $self->{data}->{errors} && $self->{data}->{errors}) {
-        $command .= ' --errors';
-    }
-
-    if (defined $self->{data}->{disable_ssl_cert} && $self->{data}->{disable_ssl_cert}) {
-        $command .= ' --disable-ssl-cert';
-    }
-
-    if (defined $self->{data}->{dry_run} && $self->{data}->{dry_run}) {
-        $command .= ' --dry-run';
-    }
-
     $command = 'zanata-cli '.$command;
 
     print "Running '$command'...\n";
@@ -145,31 +113,31 @@ sub pull_ts {
         $action .= ' --cache-dir '.$self->{data}->{cache_dir};
     }
 
-    if (defined $self->{data}->{use_cache} && $self->{data}->{use_cache}) {
-        $action .= ' --use-cache';
+    if (defined $self->{data}->{use_cache}) {
+        $action .= ' --use-cache '.$self->to_boolean($self->{data}->{use_cache});
     }
 
-    if (defined $self->{data}->{purge_cache} && $self->{data}->{purge_cache}) {
-        $action .= ' --purge-cache';
+    if (defined $self->{data}->{purge_cache}) {
+        $action .= ' --purge-cache '.$self->to_boolean($self->{data}->{purge_cache});
     }
 
     return $self->run_zanata_cli($action, $langs);
 }
 
+sub to_boolean {
+    my ($self, $boolean) = @_;
+
+    if ($boolean) {
+        return 'true';
+    }
+
+    return 'false';
+}
+
 sub push_ts {
     my ($self, $langs) = @_;
 
-    my $action = "push --push-type $self->{data}->{push_type}";
-
-    if (defined $self->{data}->{file_types}) {
-        my $file_types = $self->{data}->{file_types};
-
-        my $joined_file_types = join(',', @$file_types);
-
-        $action .= ' --file-types '.$joined_file_types;
-    }
-
-    $self->run_zanata_cli($action, $langs);
+    $self->run_zanata_cli("push --push-type $self->{data}->{push_type}", $langs);
 }
 
 1;
\ No newline at end of file
